==> qtjambi-qt3dinput-5.15.13-sources.jar: io/qt/qt3d/input/QButtonAxisInput.java <==
package io.qt.qt3d.input;


/**
 * <p>An axis input controlled by buttons The axis value is controlled by buttons rather than a traditional analog input such as a joystick</p>
 * <p>Java wrapper for Qt's class <a href="http://doc.qt.io/qt-5/qt3dinput-qbuttonaxisinput.html">Qt3DInput::QButtonAxisInput</a></p>
 */
public class QButtonAxisInput extends io.qt.qt3d.input.QAbstractAxisInput
{
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QButtonAxisInput.class);
    

    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dinput-qbuttonaxisinput.html#acceleration-prop">Qt3DInput::QButtonAxisInput::accelerationChanged(float)</a></p>
     */
    @io.qt.QtPropertyNotify(name="acceleration")
    public final Signal1<@io.qt.QtPrimitiveType Float> accelerationChanged = new Signal1<>();

    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dinput-qbuttonaxisinput.html#buttons-prop">Qt3DInput::QButtonAxisInput::buttonsChanged(QVector&lt;int&gt;)</a></p>
     */
    @io.qt.QtPropertyNotify(name="buttons")
    public final Signal1<java.util.List<java.lang.Integer>> buttonsChanged = new Signal1<>();

    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dinput-qbuttonaxisinput.html#deceleration-prop">Qt3DInput::QButtonAxisInput::decelerationChanged(float)</a></p>
     */
    @io.qt.QtPropertyNotify(name="deceleration")
    public final Signal1<@io.qt.QtPrimitiveType Float> decelerationChanged = new Signal1<>();

    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dinput-qbuttonaxisinput.html#scale-prop">Qt3DInput::QButtonAxisInput::scaleChanged(float)</a></p>
     */
    @io.qt.QtPropertyNotify(name="scale")
    public final Signal1<@io.qt.QtPrimitiveType Float> scaleChanged = new Signal1<>();
    
    /**
     * <p>Overloaded constructor for {@link #QButtonAxisInput(io.qt.qt3d.core.QNode)}
     *  with <code>parent = null</code>.</p>
     */
    public QButtonAxisInput() {
        this((io.qt.qt3d.core.QNode)null);
    }
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dinput-qbuttonaxisinput.html#QButtonAxisInput">Qt3DInput::QButtonAxisInput::QButtonAxisInput(Qt3DCore::QNode*)</a></p>
     */
    @SuppressWarnings({"exports"})
    public QButtonAxisInput(io.qt.qt3d.core.QNode parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QButtonAxisInput instance, io.qt.qt3d.core.QNode parent);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dinput-qbuttonaxisinput.html#acceleration-prop">Qt3DInput::QButtonAxisInput::acceleration()const</a></p>
     */
    @io.qt.QtPropertyReader(name="acceleration")
    @io.qt.QtUninvokable
    public final float acceleration(){
        return acceleration_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native float acceleration_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dinput-qbuttonaxisinput.html#buttons-prop">Qt3DInput::QButtonAxisInput::buttons()const</a></p>
     */
    @io.qt.QtPropertyReader(name="buttons")
    @io.qt.QtUninvokable
    public final io.qt.core.QVector<java.lang.Integer> buttons(){
        return buttons_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.core.QVector<java.lang.Integer> buttons_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dinput-qbuttonaxisinput.html#deceleration-prop">Qt3DInput::QButtonAxisInput::deceleration()const</a></p>
     */
    @io.qt.QtPropertyReader(name="deceleration")
    @io.qt.QtUninvokable
    public final float deceleration(){
        return deceleration_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native float deceleration_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dinput-qbuttonaxisinput.html#scale-prop">Qt3DInput::QButtonAxisInput::scale()const</a></p>
     */
    @io.qt.QtPropertyReader(name="scale")
    @io.qt.QtUninvokable
    public final float scale(){
        return scale_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native float scale_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dinput-qbuttonaxisinput.html#acceleration-prop">Qt3DInput::QButtonAxisInput::setAcceleration(float)</a></p>
     */
    @io.qt.QtPropertyWriter(name="acceleration")
    public final void setAcceleration(float acceleration){
        setAcceleration_native_float(QtJambi_LibraryUtilities.internal.nativeId(this), acceleration);
    }
    
    private native void setAcceleration_native_float(long __this__nativeId, float acceleration);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dinput-qbuttonaxisinput.html#buttons-prop">Qt3DInput::QButtonAxisInput::setButtons(QVector&lt;int&gt;)</a></p>
     */
    @io.qt.QtPropertyWriter(name="buttons")
    public final void setButtons(java.util.Collection<java.lang.Integer> buttons){
        setButtons_native_cref_QVector(QtJambi_LibraryUtilities.internal.nativeId(this), buttons);
    }
    
    private native void setButtons_native_cref_QVector(long __this__nativeId, java.util.Collection<java.lang.Integer> buttons);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dinput-qbuttonaxisinput.html#deceleration-prop">Qt3DInput::QButtonAxisInput::setDeceleration(float)</a></p>
     */
    @io.qt.QtPropertyWriter(name="deceleration")
    public final void setDeceleration(float deceleration){
        setDeceleration_native_float(QtJambi_LibraryUtilities.internal.nativeId(this), deceleration);
    }
    
    private native void setDeceleration_native_float(long __this__nativeId, float deceleration);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dinput-qbuttonaxisinput.html#scale-prop">Qt3DInput::QButtonAxisInput::setScale(float)</a></p>
     */
    @io.qt.QtPropertyWriter(name="scale")
    public final void setScale(float scale){
        setScale_native_float(QtJambi_LibraryUtilities.internal.nativeId(this), scale);
    }
    
    private native void setScale_native_float(long __this__nativeId, float scale);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QButtonAxisInput(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QButtonAxisInput(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QButtonAxisInput instance, QDeclarativeConstructor constructor);
    
}

==> qtjambi-qt3dinput-6.2.3-sources.jar: io/qt/qt3d/input/QButtonAxisInput.java <==
package io.qt.qt3d.input;


/**
 * <p>An axis input controlled by buttons The axis value is controlled by buttons rather than a traditional analog input such as a joystick</p>
 * <p>Java wrapper for Qt class <a href="https://doc.qt.io/qt/qt3dinput-qbuttonaxisinput.html">Qt3DInput::QButtonAxisInput</a></p>
 */
public class QButtonAxisInput extends io.qt.qt3d.input.QAbstractAxisInput
{
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QButtonAxisInput.class);
    

    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3dinput-qbuttonaxisinput.html#acceleration-prop">Qt3DInput::QButtonAxisInput::accelerationChanged(float)</a></p>
     */
    @io.qt.QtPropertyNotify(name="acceleration")
    public final Signal1<@io.qt.QtPrimitiveType Float> accelerationChanged = new Signal1<>();

    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3dinput-qbuttonaxisinput.html#buttons-prop">Qt3DInput::QButtonAxisInput::buttonsChanged(QList&lt;int&gt;)</a></p>
     */
    @io.qt.QtPropertyNotify(name="buttons")
    public final Signal1<java.util.List<java.lang.Integer>> buttonsChanged = new Signal1<>();

    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3dinput-qbuttonaxisinput.html#deceleration-prop">Qt3DInput::QButtonAxisInput::decelerationChanged(float)</a></p>
     */
    @io.qt.QtPropertyNotify(name="deceleration")
    public final Signal1<@io.qt.QtPrimitiveType Float> decelerationChanged = new Signal1<>();

    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3dinput-qbuttonaxisinput.html#scale-prop">Qt3DInput::QButtonAxisInput::scaleChanged(float)</a></p>
     */
    @io.qt.QtPropertyNotify(name="scale")
    public final Signal1<@io.qt.QtPrimitiveType Float> scaleChanged = new Signal1<>();
    
    /**
     * <p>Overloaded constructor for {@link #QButtonAxisInput(io.qt.qt3d.core.QNode)}
     *  with <code>parent = null</code>.</p>
     */
    public QButtonAxisInput() {
        this((io.qt.qt3d.core.QNode)null);
    }
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3dinput-qbuttonaxisinput.html#QButtonAxisInput">Qt3DInput::QButtonAxisInput::QButtonAxisInput(Qt3DCore::QNode*)</a></p>
     */
    @SuppressWarnings({"exports"})
    public QButtonAxisInput(io.qt.qt3d.core.QNode parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QButtonAxisInput instance, io.qt.qt3d.core.QNode parent);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3dinput-qbuttonaxisinput.html#acceleration-prop">Qt3DInput::QButtonAxisInput::acceleration()const</a></p>
     */
    @io.qt.QtPropertyReader(name="acceleration")
    @io.qt.QtUninvokable
    public final float acceleration(){
        return acceleration_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native float acceleration_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3dinput-qbuttonaxisinput.html#buttons-prop">Qt3DInput::QButtonAxisInput::buttons()const</a></p>
     */
    @io.qt.QtPropertyReader(name="buttons")
    @io.qt.QtUninvokable
    public final io.qt.core.QList<java.lang.Integer> buttons(){
        return buttons_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.core.QList<java.lang.Integer> buttons_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3dinput-qbuttonaxisinput.html#deceleration-prop">Qt3DInput::QButtonAxisInput::deceleration()const</a></p>
     */
    @io.qt.QtPropertyReader(name="deceleration")
    @io.qt.QtUninvokable
    public final float deceleration(){
        return deceleration_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native float deceleration_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3dinput-qbuttonaxisinput.html#scale-prop">Qt3DInput::QButtonAxisInput::scale()const</a></p>
     */
    @io.qt.QtPropertyReader(name="scale")
    @io.qt.QtUninvokable
    public final float scale(){
        return scale_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native float scale_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3dinput-qbuttonaxisinput.html#acceleration-prop">Qt3DInput::QButtonAxisInput::setAcceleration(float)</a></p>
     */
    @io.qt.QtPropertyWriter(name="acceleration")
    public final void setAcceleration(float acceleration){
        setAcceleration_native_float(QtJambi_LibraryUtilities.internal.nativeId(this), acceleration);
    }
    
    private native void setAcceleration_native_float(long __this__nativeId, float acceleration);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3dinput-qbuttonaxisinput.html#buttons-prop">Qt3DInput::QButtonAxisInput::setButtons(QList&lt;int&gt;)</a></p>
     */
    @io.qt.QtPropertyWriter(name="buttons")
    public final void setButtons(java.util.Collection<java.lang.Integer> buttons){
        setButtons_native_cref_QList(QtJambi_LibraryUtilities.internal.nativeId(this), buttons);
    }
    
    private native void setButtons_native_cref_QList(long __this__nativeId, java.util.Collection<java.lang.Integer> buttons);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3dinput-qbuttonaxisinput.html#deceleration-prop">Qt3DInput::QButtonAxisInput::setDeceleration(float)</a></p>
     */
    @io.qt.QtPropertyWriter(name="deceleration")
    public final void setDeceleration(float deceleration){
        setDeceleration_native_float(QtJambi_LibraryUtilities.internal.nativeId(this), deceleration);
    }
    
    private native void setDeceleration_native_float(long __this__nativeId, float deceleration);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3dinput-qbuttonaxisinput.html#scale-prop">Qt3DInput::QButtonAxisInput::setScale(float)</a></p>
     */
    @io.qt.QtPropertyWriter(name="scale")
    public final void setScale(float scale){
        setScale_native_float(QtJambi_LibraryUtilities.internal.nativeId(this), scale);
    }
    
    private native void setScale_native_float(long __this__nativeId, float scale);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QButtonAxisInput(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QButtonAxisInput(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QButtonAxisInput instance, QDeclarativeConstructor constructor);
    
}
